#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2009 florian.leparoux@gmail.com
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua54
%define mod_name    luaexpat
Version:        1.5.1
Release:        1.3
Summary:        A SAX XML parser based on the Expat library
License:        MIT
Group:          Productivity/Networking/Other
URL:            https://lunarmodules.github.io/luaexpat/
Source:         https://github.com/lunarmodules/luaexpat/archive/%{version}/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{flavor}-devel
# See: https://github.com/lunarmodules/luaexpat/releases/tag/1.5.0
BuildRequires:  libexpat-devel >= 2.4.6
BuildRequires:  lua-macros
Requires:       %{flavor}
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
LuaExpat is a SAX XML parser based on the Expat library.

%prep
%setup -q -n %{mod_name}-%{version}

%build
make %{?_smp_mflags} \
    PREFIX="%{_prefix}" \
    LUA_V=%{lua_version} \
    LUA_CDIR="%{lua_archdir}" \
    LUA_INC="-I%{lua_incdir}" \
    CFLAGS="%{optflags}"

%install
%make_install \
    PREFIX="%{_prefix}" \
    LUA_CDIR="%{lua_archdir}" \
    LUA_LDIR="%{lua_noarchdir}"

%files
%defattr(-,root,root)
%license LICENSE
%{lua_archdir}/lxp.so
%{lua_noarchdir}/lxp

%changelog
* Tue Jul 11 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to version 1.5.1:
  * Added option "allowDTD" to the threat protection parser
  * Add configuration for Billion Laughs Attack prevention
  * Expose Expat compile time constants (lxp._EXPAT_FEATURES)
  * lxp now uses $(INSTALL_DATA)
  * makefile now uses $(RPM_OPT_FLAGS) $(RPM_LD_FLAGS)
* Thu Mar 16 2023 Matej Cepl <mcepl@suse.com>
- Change upstream homepage to the current one at Lunar Modules.
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix missing dependency on lua-macros (boo#1205612)
* Tue Aug 23 2022 Callum Farmer <gmbr3@opensuse.org>
- Drop LUA_32BITS and GNU11 std - seems fixed now
* Sun Aug 21 2022 Gordon Leung <pirateclip@protonmail.com>
- Replace deprecated %%makeinstall with %%make_install
* Sat Aug 20 2022 Gordon Leung <pirateclip@protonmail.com>
- Update to version 1.4.1:
  * Fix bad buffer size calculation in threat parser
  * Improved Lua version support (5.1 - 5.4)
  * Fix memory leak when callbacks reference a parser object
  * etc. https://github.com/lunarmodules/luaexpat/releases/tag/1.4.0
* Thu Aug 12 2021 Callum Farmer <gmbr3@opensuse.org>
- Use GNU11 instead of C99
* Fri Apr  9 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix build with Lua 5.4.3
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Aug  4 2017 tchvatal@suse.com
- Install license file
* Thu Jul 13 2017 tchvatal@suse.com
- Drop not needed luaexpat-lib.patch
- Fix detection of some lua based items for 5.2 and 5.3
- Switch to multibuild specfile to build against all lua flavors
- Fix build on lua5.3
* Wed May 28 2014 seiler@b1-systems.de
- update to v1.3.0
  * Lua 5.2 support (thanks Tomás Guisasola Gorham)
  * support for the XmlDecl handler
  * add parser:getcurrentbytecount() (XML_GetCurrentByteCount)
  * ability to disable CharacterData merging
  * Makefile improvements (thanks Vadim Misbakh-Soloviov)
* Sat Jun 29 2013 i@marguerite.su
- update version 1.2.0
  * support for the StartDoctypeDecl handler
  * add parser:stop() to abort parsing inside a callback
* Tue Apr 17 2012 toganm@opensuse.org
- Cleanup spec and create changes file
  * correct Licence to MIT
  * fix build for factory by using lua51-devel
  * fix build for SLE_11 and SLE_11_SP1
  * add copyright to spec
* Sat Jan 23 2010 florian.leparoux@gmail.com
- rebuild correctly luaexpat on openSUSE 11.2
* Tue Dec 15 2009 florian.leparoux@gmail.com
- build luaexpat on openSUSE 11.2
